import { ElementRef, OnInit, TemplateRef, ChangeDetectorRef, OnDestroy } from '@angular/core';
import { IgxIconService } from './icon.service';
export declare class IgxIconComponent implements OnInit, OnDestroy {
    private _el;
    private iconService;
    private ref;
    private noLigature;
    private explicitLigature;
    private svgImage;
    private destroy$;
    /**
     *  This allows you to change the value of `class.igx-icon`. By default it's `igx-icon`.
     *
     * @hidden
     * @internal
     */
    cssClass: string;
    /**
     *  This allows you to disable the `aria-hidden` attribute. By default it's applied.
     * @example
     * ```typescript
     * @ViewChild("MyIcon") public icon: IgxIconComponent;
     * constructor(private cdRef:ChangeDetectorRef) {}
     * ngAfterViewInit() {
     *     this.icon.ariaHidden = false;
     *     this.cdRef.detectChanges();
     * }
     * ```
     */
    ariaHidden: boolean;
    /**
     * An @Input property that sets the value of the `id` attribute.
     * @example
     * ```html
     * <igx-icon id="igx-icon-1" fontSet="material">settings</igx-icon>
     * ```
     */
    id: string;
    /**
     * An @Input property that sets the value of the `fontSet`. By default it's "material".
     * @example
     * ```html
     * <igx-icon fontSet="material">settings</igx-icon>
     * ```
     */
    font: string;
    /**
     * An @Input property that allows you to disable the `active` property. By default it's applied.
     * @example
     * ```html
     * <igx-icon [isActive]="false">settings</igx-icon>
     * ```
     */
    active: boolean;
    /**
     * An @Input property that allows you to change the `iconColor` of the icon.
     * @example
     * ```html
     * <igx-icon color="blue">settings</igx-icon>
     * ```
     */
    iconColor: string;
    /**
     *  An @Input property that allows you to set the `iconName` of the icon.
     *  @example
     * ```html
     * <igx-icon name="contains" fontSet="filter-icons"></igx-icon>
     * ```
     */
    iconName: string;
    /**
     * An ElementRef property of the `igx-icon` component.
     */
    el: ElementRef;
    constructor(_el: ElementRef, iconService: IgxIconService, ref: ChangeDetectorRef);
    /**
     * @hidden
     * @internal
     */
    ngOnInit(): void;
    /**
     * @hidden
     * @internal
     */
    ngOnDestroy(): void;
    /**
     *  An accessor that returns the value of the font property.
     * @example
     * ```typescript
     *  @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconFont = this.icon.getFontSet;
     * }
     * ```
     */
    get getFontSet(): string;
    /**
     *  An accessor that returns the value of the active property.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconActive = this.icon.getActive;
     * }
     * ```
     */
    get getActive(): boolean;
    /**
     *  An accessor that returns inactive property.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconActive = this.icon.getInactive;
     * }
     * ```
     */
    get getInactive(): boolean;
    /**
     * An accessor that returns the opposite value of the `iconColor` property.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconColor = this.icon.getIconColor;
     * }
     * ```
     */
    get getIconColor(): string;
    /**
     * An accessor that returns the value of the iconName property.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconName = this.icon.getIconName;
     * }
     * ```
     */
    get getIconName(): string;
    /**
     *  An accessor that returns the key of the SVG image.
     *  The key consists of the fontSet and the iconName separated by underscore.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let svgKey = this.icon.getSvgKey;
     * }
     * ```
     */
    get getSvgKey(): string;
    /**
     *   An accessor that returns a TemplateRef to explicit, svg or no ligature.
     * @example
     * ```typescript
     * @ViewChild("MyIcon")
     * public icon: IgxIconComponent;
     * ngAfterViewInit() {
     *    let iconTemplate = this.icon.template;
     * }
     * ```
     */
    get template(): TemplateRef<HTMLElement>;
    /**
     * @hidden
     * @internal
     */
    private updateIconClass;
}
