"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../common/util");
const UpdateChanges_1 = require("../common/UpdateChanges");
const version = '8.2.6';
function default_1() {
    return (host, context) => {
        const themes = ['$_base-dark-grid-pagination',
            '$_dark-grid-pagination',
            '$_dark-fluent-grid-pagination',
            '$_light-grid-pagination',
            '$_fluent-grid-pagination',
            '$_round-shape-grid-pagination',
            '$_default-shape-grid-pagination',
            '$_square-shape-grid-pagination'];
        const newThemes = ['$_base-dark-pagination',
            '$_dark-pagination',
            '$_dark-fluent-pagination',
            '$_light-pagination',
            '$_fluent-pagination',
            '$_round-shape-pagination',
            '$_default-shape-pagination',
            '$_square-shape-pagination'];
        let globalStyleExt;
        const gridPaginatorComponentImport = '~igniteui-angular/lib/core/styles/components/grid-paginator/grid-paginator-component';
        const gridPaginatorThemeImport = '~igniteui-angular/lib/core/styles/components/grid-paginator/grid-paginator-theme';
        const paginatorComponentImport = '~igniteui-angular/lib/core/styles/components/paginator/paginator-component';
        const paginatorThemeImport = '~igniteui-angular/lib/core/styles/components/paginator/paginator-theme';
        const config = util_1.getWorkspace(host);
        const projects = util_1.getProjects(config);
        context.logger.info(`Applying migration for Ignite UI for Angular to version ${version}`);
        const update = new UpdateChanges_1.UpdateChanges(__dirname, host, context);
        if (config.schematics && config.schematics['@schematics/angular:component']) {
            // updated projects have global prefix rather than per-project:
            globalStyleExt = config.schematics['@schematics/angular:component'].styleext;
        }
        for (const proj of projects) {
            const dir = host.getDir(proj.sourceRoot);
            let ext = globalStyleExt || 'scss';
            if (proj.schematics && proj.schematics['@schematics/angular:component']) {
                ext = proj.schematics['@schematics/angular:component'].styleext || ext;
            }
            dir.visit((path, entry) => {
                if (path.endsWith('.' + ext)) {
                    let content = entry.content.toString();
                    if (content.match(/\bigx-grid-paginator\b/g)) {
                        content = content.replace(/\bigx-grid-paginator\b/g, 'igx-paginator');
                    }
                    themes.forEach((n, i) => {
                        if (content.indexOf(n) !== -1) {
                            content = content.split(n).join(newThemes[i]);
                        }
                    });
                    if (content.indexOf(gridPaginatorComponentImport) !== -1) {
                        content = content.replace(gridPaginatorComponentImport, paginatorComponentImport);
                        host.overwrite(path, content);
                    }
                    if (content.indexOf(gridPaginatorThemeImport) !== -1) {
                        content = content.replace(gridPaginatorThemeImport, paginatorThemeImport);
                        host.overwrite(path, content);
                    }
                    host.overwrite(path, content);
                }
            });
        }
        update.applyChanges();
    };
}
exports.default = default_1;
